'''OpenGL extension ARB.texture_cube_map_array

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_cube_map_array to provide a more 
Python-friendly API

Overview (from the spec)
	
	The GL_EXT_texture_array extension, and subsequently OpenGL 3.0 have
	introduced the concept of one- and two-dimensional array textures.
	An array texture is an ordered set of images with the same size and
	format. Each image in an array texture has a unique level. This
	extension expands texture array support to include cube map
	textures.
	
	A cube map array texture is a 2-dimensional array texture that may
	contain many cube map layers. Each cube map layer is a unique cube
	map image set. Images in a cube map array have the same size and
	format limitations as one- and two-dimensional array textures. A
	cube map array texture is specified using TexImage3D in a similar
	manner to two-dimensional arrays. Cube map array textures can be
	bound to a render targets of a frame buffer object as
	two-dimensional arrays are using FramebufferTextureLayer.
	
	When accessed by a programmable shader, a cube map array texture
	acts as a single unit. The "s", "t", "r" texture coordinates are
	treated as a regular cube map texture fetch. The "q" texture is
	treated as an unnormalized floating-point value identifying the
	layer of the cube map array texture. Cube map array texture lookups
	do not filter between layers.
	
	This extension does not provide for the use of cube map array
	textures with fixed-function fragment processing.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_cube_map_array.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_cube_map_array import *
from OpenGL.raw.GL.ARB.texture_cube_map_array import _EXTENSION_NAME

def glInitTextureCubeMapArrayARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.fragment_program2

This module customises the behaviour of the 
OpenGL.raw.GL.NV.fragment_program2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension, like the NV_fragment_program_option extension, provides
	additional fragment program functionality to extend the standard
	ARB_fragment_program language and execution environment.  ARB programs
	wishing to use this added functionality need only add:
	
	    OPTION NV_fragment_program2;
	
	to the beginning of their fragment programs.
	
	New functionality provided by this extension, above and beyond that
	already provided by the NV_fragment_program_option extension, includes:
	
	
	  * structured branching support, including data-dependent IF tests, loops
	    supporting a fixed number of iterations, and a data-dependent loop
	    exit instruction (BRK),
	
	  * subroutine calls,
	
	  * instructions to perform vector normalization, divide vector components
	    by a scalar, and perform two-component dot products (with or without a
	    scalar add),
	
	  * an instruction to perform a texture lookup with an explicit LOD,
	
	  * a loop index register for indirect access into the texture coordinate
	    attribute array, and
	
	  * a facing attribute that indicates whether the fragment is generated
	    from a front- or back-facing primitive.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/fragment_program2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.fragment_program2 import *
from OpenGL.raw.GL.NV.fragment_program2 import _EXTENSION_NAME

def glInitFragmentProgram2NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGI.video_sync

This module customises the behaviour of the 
OpenGL.raw.GLX.SGI.video_sync to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a means for synchronization with the video 
	frame rate of a monitor.  (In the case of an interlaced monitor, 
	this is typically the rate of displaying both the even and odd 
	fields of a frame.) The kernel maintains a video sync counter for 
	each physical hardware pipe in a system; the counter is incremented 
	upon the completion of the display of each full frame of video data. An
	OpenGL context always corresponds to a pipe.  When an OpenGL process
	has a current context, it can put itself to sleep until the counter of
	that pipe reaches a desired value.  The process can also query the
	value of the counter.
	
	The counter runs as long as the graphics subsystem is running; it is
	initialized via the /usr/gfx/gfxinit command.  However, a process can
	query or sleep on the counter only when a direct context is current.
	Each of the procedures described below will fail and return an error
	code if the current context is not a direct one.
	
	The counter is an unsigned 32-bit integer.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGI/video_sync.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.SGI.video_sync import *
from OpenGL.raw.GLX.SGI.video_sync import _EXTENSION_NAME

def glInitVideoSyncSGI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_ANGLE_framebuffer_blit'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_ANGLE_framebuffer_blit',error_checker=_errors._error_checker)
GL_DRAW_FRAMEBUFFER_ANGLE=_C('GL_DRAW_FRAMEBUFFER_ANGLE',0x8CA9)
GL_DRAW_FRAMEBUFFER_BINDING_ANGLE=_C('GL_DRAW_FRAMEBUFFER_BINDING_ANGLE',0x8CA6)
GL_READ_FRAMEBUFFER_ANGLE=_C('GL_READ_FRAMEBUFFER_ANGLE',0x8CA8)
GL_READ_FRAMEBUFFER_BINDING_ANGLE=_C('GL_READ_FRAMEBUFFER_BINDING_ANGLE',0x8CAA)
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLbitfield,_cs.GLenum)
def glBlitFramebufferANGLE(srcX0,srcY0,srcX1,srcY1,dstX0,dstY0,dstX1,dstY1,mask,filter):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_OES_geometry_shader'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_OES_geometry_shader',error_checker=_errors._error_checker)
GL_FIRST_VERTEX_CONVENTION_OES=_C('GL_FIRST_VERTEX_CONVENTION_OES',0x8E4D)
GL_FRAMEBUFFER_ATTACHMENT_LAYERED_OES=_C('GL_FRAMEBUFFER_ATTACHMENT_LAYERED_OES',0x8DA7)
GL_FRAMEBUFFER_DEFAULT_LAYERS_OES=_C('GL_FRAMEBUFFER_DEFAULT_LAYERS_OES',0x9312)
GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_OES=_C('GL_FRAMEBUFFER_INCOMPLETE_LAYER_TARGETS_OES',0x8DA8)
GL_GEOMETRY_LINKED_INPUT_TYPE_OES=_C('GL_GEOMETRY_LINKED_INPUT_TYPE_OES',0x8917)
GL_GEOMETRY_LINKED_OUTPUT_TYPE_OES=_C('GL_GEOMETRY_LINKED_OUTPUT_TYPE_OES',0x8918)
GL_GEOMETRY_LINKED_VERTICES_OUT_OES=_C('GL_GEOMETRY_LINKED_VERTICES_OUT_OES',0x8916)
GL_GEOMETRY_SHADER_BIT_OES=_C('GL_GEOMETRY_SHADER_BIT_OES',0x00000004)
GL_GEOMETRY_SHADER_INVOCATIONS_OES=_C('GL_GEOMETRY_SHADER_INVOCATIONS_OES',0x887F)
GL_GEOMETRY_SHADER_OES=_C('GL_GEOMETRY_SHADER_OES',0x8DD9)
GL_LAST_VERTEX_CONVENTION_OES=_C('GL_LAST_VERTEX_CONVENTION_OES',0x8E4E)
GL_LAYER_PROVOKING_VERTEX_OES=_C('GL_LAYER_PROVOKING_VERTEX_OES',0x825E)
GL_LINES_ADJACENCY_OES=_C('GL_LINES_ADJACENCY_OES',0x000A)
GL_LINE_STRIP_ADJACENCY_OES=_C('GL_LINE_STRIP_ADJACENCY_OES',0x000B)
GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS_OES=_C('GL_MAX_COMBINED_GEOMETRY_UNIFORM_COMPONENTS_OES',0x8A32)
GL_MAX_FRAMEBUFFER_LAYERS_OES=_C('GL_MAX_FRAMEBUFFER_LAYERS_OES',0x9317)
GL_MAX_GEOMETRY_ATOMIC_COUNTERS_OES=_C('GL_MAX_GEOMETRY_ATOMIC_COUNTERS_OES',0x92D5)
GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS_OES=_C('GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS_OES',0x92CF)
GL_MAX_GEOMETRY_IMAGE_UNIFORMS_OES=_C('GL_MAX_GEOMETRY_IMAGE_UNIFORMS_OES',0x90CD)
GL_MAX_GEOMETRY_INPUT_COMPONENTS_OES=_C('GL_MAX_GEOMETRY_INPUT_COMPONENTS_OES',0x9123)
GL_MAX_GEOMETRY_OUTPUT_COMPONENTS_OES=_C('GL_MAX_GEOMETRY_OUTPUT_COMPONENTS_OES',0x9124)
GL_MAX_GEOMETRY_OUTPUT_VERTICES_OES=_C('GL_MAX_GEOMETRY_OUTPUT_VERTICES_OES',0x8DE0)
GL_MAX_GEOMETRY_SHADER_INVOCATIONS_OES=_C('GL_MAX_GEOMETRY_SHADER_INVOCATIONS_OES',0x8E5A)
GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS_OES=_C('GL_MAX_GEOMETRY_SHADER_STORAGE_BLOCKS_OES',0x90D7)
GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_OES=_C('GL_MAX_GEOMETRY_TEXTURE_IMAGE_UNITS_OES',0x8C29)
GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_OES=_C('GL_MAX_GEOMETRY_TOTAL_OUTPUT_COMPONENTS_OES',0x8DE1)
GL_MAX_GEOMETRY_UNIFORM_BLOCKS_OES=_C('GL_MAX_GEOMETRY_UNIFORM_BLOCKS_OES',0x8A2C)
GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_OES=_C('GL_MAX_GEOMETRY_UNIFORM_COMPONENTS_OES',0x8DDF)
GL_PRIMITIVES_GENERATED_OES=_C('GL_PRIMITIVES_GENERATED_OES',0x8C87)
GL_REFERENCED_BY_GEOMETRY_SHADER_OES=_C('GL_REFERENCED_BY_GEOMETRY_SHADER_OES',0x9309)
GL_TRIANGLES_ADJACENCY_OES=_C('GL_TRIANGLES_ADJACENCY_OES',0x000C)
GL_TRIANGLE_STRIP_ADJACENCY_OES=_C('GL_TRIANGLE_STRIP_ADJACENCY_OES',0x000D)
GL_UNDEFINED_VERTEX_OES=_C('GL_UNDEFINED_VERTEX_OES',0x8260)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint)
def glFramebufferTextureOES(target,attachment,texture,level):pass



'''OpenGL extension SGIX.async_histogram

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.async_histogram to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces a new asynchronous mode for histogram
	and minmax readbacks.  It allows programs to get the contents of a
	histogram or minmax table without blocking and to continue issuing
	graphics commands during the readback.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/async_histogram.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.async_histogram import *
from OpenGL.raw.GL.SGIX.async_histogram import _EXTENSION_NAME

def glInitAsyncHistogramSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.texture_buffer_object_rgb32

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_buffer_object_rgb32 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds three new buffer texture formats - RGB32F, RGB32I, 
	and RGB32UI.  This partially addresses one of the limitations of buffer 
	textures in the original EXT_texture_buffer_object extension and in 
	OpenGL 3.1, which provide no support for three-component formats.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_buffer_object_rgb32.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_buffer_object_rgb32 import *
from OpenGL.raw.GL.ARB.texture_buffer_object_rgb32 import _EXTENSION_NAME

def glInitTextureBufferObjectRgb32ARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.vertex_buffer_object

This module customises the behaviour of the 
OpenGL.raw.GLX.ARB.vertex_buffer_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension defines an interface that allows various types of data
	(especially vertex array data) to be cached in high-performance
	graphics memory on the server, thereby increasing the rate of data
	transfers.
	
	Chunks of data are encapsulated within "buffer objects", which
	conceptually are nothing more than arrays of bytes, just like any
	chunk of memory.  An API is provided whereby applications can read
	from or write to buffers, either via the GL itself (glBufferData,
	glBufferSubData, glGetBufferSubData) or via a pointer to the memory.
	
	The latter technique is known as "mapping" a buffer.  When an
	application maps a buffer, it is given a pointer to the memory.  When
	the application finishes reading from or writing to the memory, it is
	required to "unmap" the buffer before it is once again permitted to
	use that buffer as a GL data source or sink.  Mapping often allows
	applications to eliminate an extra data copy otherwise required to
	access the buffer, thereby enhancing performance.  In addition,
	requiring that applications unmap the buffer to use it as a data
	source or sink ensures that certain classes of latent synchronization
	bugs cannot occur.
	
	Although this extension only defines hooks for buffer objects to be
	used with OpenGL's vertex array APIs, the API defined in this
	extension permits buffer objects to be used as either data sources or
	sinks for any GL command that takes a pointer as an argument.
	Normally, in the absence of this extension, a pointer passed into the
	GL is simply a pointer to the user's data.  This extension defines
	a mechanism whereby this pointer is used not as a pointer to the data
	itself, but as an offset into a currently bound buffer object.  The
	buffer object ID zero is reserved, and when buffer object zero is
	bound to a given target, the commands affected by that buffer binding
	behave normally.  When a nonzero buffer ID is bound, then the pointer
	represents an offset.
	
	In the case of vertex arrays, this extension defines not merely one
	binding for all attributes, but a separate binding for each
	individual attribute.  As a result, applications can source their
	attributes from multiple buffers.  An application might, for example,
	have a model with constant texture coordinates and variable geometry.
	The texture coordinates might be retrieved from a buffer object with
	the usage mode "STATIC_DRAW", indicating to the GL that the
	application does not expect to update the contents of the buffer
	frequently or even at all, while the vertices might be retrieved from
	a buffer object with the usage mode "STREAM_DRAW", indicating that
	the vertices will be updated on a regular basis.
	
	In addition, a binding is defined by which applications can source
	index data (as used by DrawElements, DrawRangeElements, and
	MultiDrawElements) from a buffer object.  On some platforms, this
	enables very large models to be rendered with no more than a few
	small commands to the graphics device.
	
	It is expected that a future extension will allow sourcing pixel data
	from and writing pixel data to a buffer object.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/vertex_buffer_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.ARB.vertex_buffer_object import *
from OpenGL.raw.GLX.ARB.vertex_buffer_object import _EXTENSION_NAME

def glInitVertexBufferObjectARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.gpu_shader4

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.gpu_shader4 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a set of new features to the OpenGL Shading
	Language and related APIs to support capabilities of new hardware. In
	particular, this extension provides the following functionality:
	
	   * New texture lookup functions are provided that allow shaders to
	     access individual texels using integer coordinates referring to the
	     texel location and level of detail. No filtering is performed. These
	     functions allow applications to use textures as one-, two-, and
	     three-dimensional arrays.
	
	   * New texture lookup functions are provided that allow shaders to query
	     the dimensions of a specific level-of-detail image of a texture
	     object.
	
	   * New texture lookup functions variants are provided that allow shaders
	     to pass a constant integer vector used to offset the texel locations
	     used during the lookup to assist in custom texture filtering
	     operations.
	
	   * New texture lookup functions are provided that allow shaders to
	     access one- and two-dimensional array textures. The second, or third,
	     coordinate is used to select the layer of the array to access.
	
	   * New "Grad" texture lookup functions are provided that allow shaders
	     to explicitely pass in derivative values which are used by the GL to
	     compute the level-of-detail when performing a texture lookup.
	
	   * A new texture lookup function is provided to access a buffer texture.
	
	   * The existing absolute LOD texture lookup functions are no longer
	     restricted to the vertex shader only.
	
	   * The ability to specify and use cubemap textures with a
	     DEPTH_COMPONENT internal format. This also enables shadow mapping on
	     cubemaps. The 'q' coordinate is used as the reference value for
	     comparisons. A set of new texture lookup functions is provided to
	     lookup into shadow cubemaps.
	
	   * The ability to specify if varying variables are interpolated in a
	     non-perspective correct manner, if they are flat shaded or, if
	     multi-sampling, if centroid sampling should be performed.
	
	   * Full signed integer and unsigned integer support in the OpenGL
	     Shading Language:
	
	         - Integers are defined as 32 bit values using two's complement.
	
	         - Unsigned integers and vectors thereof are added.
	
	         - New texture lookup functions are provided that return integer
	           values. These functions are to be used in conjunction with new
	           texture formats whose components are actual integers, rather
	           than integers that encode a floating-point value. To support
	           these lookup functions, new integer and unsigned-integer
	           sampler types are introduced.
	
	         - Integer bitwise operators are now enabled.
	
	         - Several built-in functions and operators now operate on
	           integers or vectors of integers.
	
	         - New vertex attribute functions are added that load integer
	           attribute data and can be referenced in a vertex shader as
	           integer data.
	
	         - New uniform loading commands are added to load unsigned integer
	           data.
	
	         - Varying variables can now be (unsigned) integers. If declared
	           as such, they have to be flat shaded.
	
	         - Fragment shaders can define their own output variables, and
	           declare them to be of type floating-point, integer or unsigned
	           integer. These variables are bound to a fragment color index
	           with the new API command BindFragDataLocationEXT(), and directed
	           to buffers using the existing DrawBuffer or DrawBuffers API
	           commands.
	
	   * Added new built-in functions truncate() and round() to the shading
	     language.
	
	   * A new built-in variable accessible from within vertex shaders that
	     holds the index <i> implicitly passed to ArrayElement to specify the
	     vertex. This is called the vertex ID.
	
	   * A new built-in variable accessible from within fragment and geometry
	     shaders that hold the index of the currently processed
	     primitive. This is called the primitive ID.
	
	This extension also briefly mentions a new shader type, called a geometry
	shader. A geometry shader is run after vertices are transformed, but
	before clipping. A geometry shader begins with a single primitive (point,
	line, triangle. It can read the attributes of any of the vertices in the
	primitive and use them to generate new primitives. A geometry shader has a
	fixed output primitive type (point, line strip, or triangle strip) and
	emits vertices to define a new primitive. Geometry shaders are discussed
	in detail in the GL_EXT_geometry_shader4 specification.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/gpu_shader4.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.gpu_shader4 import *
from OpenGL.raw.GL.EXT.gpu_shader4 import _EXTENSION_NAME

def glInitGpuShader4EXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# OUTPUT glGetUniformuivEXT.params COMPSIZE(program, location) 
# INPUT glBindFragDataLocationEXT.name size not checked against 'name'
glBindFragDataLocationEXT=wrapper.wrapper(glBindFragDataLocationEXT).setInputArraySize(
    'name', None
)
# INPUT glGetFragDataLocationEXT.name size not checked against 'name'
glGetFragDataLocationEXT=wrapper.wrapper(glGetFragDataLocationEXT).setInputArraySize(
    'name', None
)
# INPUT glUniform1uivEXT.value size not checked against count
glUniform1uivEXT=wrapper.wrapper(glUniform1uivEXT).setInputArraySize(
    'value', None
)
# INPUT glUniform2uivEXT.value size not checked against count*2
glUniform2uivEXT=wrapper.wrapper(glUniform2uivEXT).setInputArraySize(
    'value', None
)
# INPUT glUniform3uivEXT.value size not checked against count*3
glUniform3uivEXT=wrapper.wrapper(glUniform3uivEXT).setInputArraySize(
    'value', None
)
# INPUT glUniform4uivEXT.value size not checked against count*4
glUniform4uivEXT=wrapper.wrapper(glUniform4uivEXT).setInputArraySize(
    'value', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.texture_env_dot3

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_env_dot3 to provide a more 
Python-friendly API

Overview (from the spec)
	
	Adds new operation to the texture combiner operations.
	
	    DOT3_RGB_ARB                    Arg0 <dotprod> Arg1
	    DOT3_RGBA_ARB                   Arg0 <dotprod> Arg1
	
	where Arg0, Arg1 are specified by <params> parameter of 
	TexEnvf, TexEnvi, TexEnvfv, and TexEnviv when the <pname>
	parameter value is SOURCE0_RGB_ARB and SOURCE1_RGB_ARB.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_env_dot3.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_env_dot3 import *
from OpenGL.raw.GL.ARB.texture_env_dot3 import _EXTENSION_NAME

def glInitTextureEnvDot3ARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIX_clipmap'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIX_clipmap',error_checker=_errors._error_checker)
GL_LINEAR_CLIPMAP_LINEAR_SGIX=_C('GL_LINEAR_CLIPMAP_LINEAR_SGIX',0x8170)
GL_LINEAR_CLIPMAP_NEAREST_SGIX=_C('GL_LINEAR_CLIPMAP_NEAREST_SGIX',0x844F)
GL_MAX_CLIPMAP_DEPTH_SGIX=_C('GL_MAX_CLIPMAP_DEPTH_SGIX',0x8177)
GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX=_C('GL_MAX_CLIPMAP_VIRTUAL_DEPTH_SGIX',0x8178)
GL_NEAREST_CLIPMAP_LINEAR_SGIX=_C('GL_NEAREST_CLIPMAP_LINEAR_SGIX',0x844E)
GL_NEAREST_CLIPMAP_NEAREST_SGIX=_C('GL_NEAREST_CLIPMAP_NEAREST_SGIX',0x844D)
GL_TEXTURE_CLIPMAP_CENTER_SGIX=_C('GL_TEXTURE_CLIPMAP_CENTER_SGIX',0x8171)
GL_TEXTURE_CLIPMAP_DEPTH_SGIX=_C('GL_TEXTURE_CLIPMAP_DEPTH_SGIX',0x8176)
GL_TEXTURE_CLIPMAP_FRAME_SGIX=_C('GL_TEXTURE_CLIPMAP_FRAME_SGIX',0x8172)
GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX=_C('GL_TEXTURE_CLIPMAP_LOD_OFFSET_SGIX',0x8175)
GL_TEXTURE_CLIPMAP_OFFSET_SGIX=_C('GL_TEXTURE_CLIPMAP_OFFSET_SGIX',0x8173)
GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX=_C('GL_TEXTURE_CLIPMAP_VIRTUAL_DEPTH_SGIX',0x8174)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_EXT_create_context_robustness'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_EXT_create_context_robustness',error_checker=_errors._error_checker)
EGL_CONTEXT_OPENGL_RESET_NOTIFICATION_STRATEGY_EXT=_C('EGL_CONTEXT_OPENGL_RESET_NOTIFICATION_STRATEGY_EXT',0x3138)
EGL_CONTEXT_OPENGL_ROBUST_ACCESS_EXT=_C('EGL_CONTEXT_OPENGL_ROBUST_ACCESS_EXT',0x30BF)
EGL_LOSE_CONTEXT_ON_RESET_EXT=_C('EGL_LOSE_CONTEXT_ON_RESET_EXT',0x31BF)
EGL_NO_RESET_NOTIFICATION_EXT=_C('EGL_NO_RESET_NOTIFICATION_EXT',0x31BE)




'''OpenGL extension EXT.separate_specular_color

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.separate_specular_color to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds a second color to rasterization when lighting is 
	enabled.  Its purpose is to produce textured objects with specular 
	highlights which are the color of the lights.  It applies only to 
	rgba lighting.
	
	The two colors are computed at the vertexes.  They are both clamped, 
	flat-shaded, clipped, and converted to fixed-point just like the 
	current rgba color (see Figure 2.8).  Rasterization interpolates 
	both colors to fragments.  If texture is enabled, the first (or 
	primary) color is the input to the texture environment; the fragment 
	color is the sum of the second color and the color resulting from 
	texture application.  If texture is not enabled, the fragment color 
	is the sum of the two colors.
	
	A new control to LightModel*, LIGHT_MODEL_COLOR_CONTROL_EXT, manages 
	the values of the two colors.  It takes values: SINGLE_COLOR_EXT, a 
	compatibility mode, and SEPARATE_SPECULAR_COLOR_EXT, the object of 
	this extension.  In single color mode, the primary color is the 
	current final color and the secondary color is 0.0.  In separate 
	specular mode, the primary color is the sum of the ambient, diffuse, 
	and emissive terms of final color and the secondary color is the 
	specular term.
	
	There is much concern that this extension may not be compatible with
	the future direction of OpenGL with regards to better lighting and
	shading models.  Until those impacts are resolved, serious
	consideration should be given before adding to the interface
	specified herein (for example, allowing the user to specify a
	second input color).

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/separate_specular_color.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.separate_specular_color import *
from OpenGL.raw.GL.EXT.separate_specular_color import _EXTENSION_NAME

def glInitSeparateSpecularColorEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.draw_indirect

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.draw_indirect to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism for supplying the arguments to a 
	DrawArraysInstanced or DrawElementsInstancedBaseVertex from buffer object
	memory. This is not particularly useful for applications where the CPU 
	knows the values of the arguments beforehand, but is helpful when the 
	values will be generated on the GPU through any mechanism that can write
	to a buffer object including image stores, atomic counters, or compute
	interop. This allows the GPU to consume these arguments without a round-
	trip to the CPU or the expensive synchronization that would involve. This
	is similar to the DrawTransformFeedbackEXT command from 
	EXT_transform_feedback2, but offers much more flexibility in both 
	generating the arguments and in the type of Draws that can be accomplished.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/draw_indirect.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.draw_indirect import *
from OpenGL.raw.GL.ARB.draw_indirect import _EXTENSION_NAME

def glInitDrawIndirectARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.vertex_program2

This module customises the behaviour of the 
OpenGL.raw.GL.NV.vertex_program2 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension further enhances the concept of vertex programmability
	introduced by the NV_vertex_program extension, and extended by
	NV_vertex_program1_1.  These extensions create a separate vertex program
	mode where the configurable vertex transformation operations in unextended
	OpenGL are replaced by a user-defined program.
	
	This extension introduces the VP2 execution environment, which extends the
	VP1 execution environment introduced in NV_vertex_program.  The VP2
	environment provides several language features not present in previous
	vertex programming execution environments:
	
	  * Branch instructions allow a program to jump to another instruction
	    specified in the program.
	
	  * Branching support allows for up to four levels of subroutine
	    calls/returns.
	
	  * A four-component condition code register allows an application to
	    compute a component-wise write mask at run time and apply that mask to
	    register writes.  
	
	  * Conditional branches are supported, where the condition code register
	    is used to determine if a branch should be taken.
	
	  * Programmable user clipping is supported support (via the CLP0-CLP5
	    clip distance registers).  Primitives are clipped to the area where
	    the interpolated clip distances are greater than or equal to zero.
	
	  * Instructions can perform a component-wise absolute value operation on
	    any operand load.
	
	The VP2 execution environment provides a number of new instructions, and
	extends the semantics of several instructions already defined in
	NV_vertex_program.
	
	  * ARR:  Operates like ARL, except that float-to-int conversion is done
	    by rounding.  Equivalent results could be achieved (less efficiently)
	    in NV_vertex program using an ADD/ARL sequence and a program parameter
	    holding the value 0.5.
	
	  * BRA, CAL, RET:  Branch, subroutine call, and subroutine return
	    instructions.
	
	  * COS, SIN:  Adds support for high-precision sine and cosine
	    computations.
	
	  * FLR, FRC:  Adds support for computing the floor and fractional portion
	    of floating-point vector components.  Equivalent results could be
	    achieved (less efficiently) in NV_vertex_program using the EXP
	    instruction to compute the fractional portion of one component at a
	    time.
	
	  * EX2, LG2:  Adds support for high-precision exponentiation and
	    logarithm computations.
	
	  * ARA:  Adds pairs of components of an address register; useful for
	    looping and other operations.
	
	  * SEQ, SFL, SGT, SLE, SNE, STR:  Add six new "set on" instructions,
	    similar to the SLT and SGE instructions defined in NV_vertex_program.
	    Equivalent results could be achieved (less efficiently) in
	    NV_vertex_program with multiple SLT, SGE, and arithmetic instructions.
	
	  * SSG:  Adds a new "set sign" operation, which produces a vector holding
	    negative one for negative components, zero for components with a value
	    of zero, and positive one for positive components.  Equivalent results
	    could be achieved (less efficiently) in NV_vertex_program with
	    multiple SLT, SGE, and arithmetic instructions.
	
	  * The ARL instruction is extended to operate on four components instead
	    of a single component.
	
	  * All instructions that produce integer or floating-point result vectors
	    have variants that update the condition code register based on the
	    result vector.
	
	This extension also raises some of the resource limitations in the
	NV_vertex_program extension.
	
	  * 256 program parameter registers (versus 96 in NV_vertex_program).
	
	  * 16 temporary registers (versus 12 in NV_vertex_program).
	
	  * Two four-component integer address registers (versus one
	    single-component register in NV_vertex_program).
	
	  * 256 total vertex program instructions (versus 128 in
	    NV_vertex_program).
	
	  * Including loops, programs can execute up to 64K instructions.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/vertex_program2.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.vertex_program2 import *
from OpenGL.raw.GL.NV.vertex_program2 import _EXTENSION_NAME

def glInitVertexProgram2NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIX_fragment_lighting'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIX_fragment_lighting',error_checker=_errors._error_checker)
GL_CURRENT_RASTER_NORMAL_SGIX=_C('GL_CURRENT_RASTER_NORMAL_SGIX',0x8406)
GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX=_C('GL_FRAGMENT_COLOR_MATERIAL_FACE_SGIX',0x8402)
GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX=_C('GL_FRAGMENT_COLOR_MATERIAL_PARAMETER_SGIX',0x8403)
GL_FRAGMENT_COLOR_MATERIAL_SGIX=_C('GL_FRAGMENT_COLOR_MATERIAL_SGIX',0x8401)
GL_FRAGMENT_LIGHT0_SGIX=_C('GL_FRAGMENT_LIGHT0_SGIX',0x840C)
GL_FRAGMENT_LIGHT1_SGIX=_C('GL_FRAGMENT_LIGHT1_SGIX',0x840D)
GL_FRAGMENT_LIGHT2_SGIX=_C('GL_FRAGMENT_LIGHT2_SGIX',0x840E)
GL_FRAGMENT_LIGHT3_SGIX=_C('GL_FRAGMENT_LIGHT3_SGIX',0x840F)
GL_FRAGMENT_LIGHT4_SGIX=_C('GL_FRAGMENT_LIGHT4_SGIX',0x8410)
GL_FRAGMENT_LIGHT5_SGIX=_C('GL_FRAGMENT_LIGHT5_SGIX',0x8411)
GL_FRAGMENT_LIGHT6_SGIX=_C('GL_FRAGMENT_LIGHT6_SGIX',0x8412)
GL_FRAGMENT_LIGHT7_SGIX=_C('GL_FRAGMENT_LIGHT7_SGIX',0x8413)
GL_FRAGMENT_LIGHTING_SGIX=_C('GL_FRAGMENT_LIGHTING_SGIX',0x8400)
GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX=_C('GL_FRAGMENT_LIGHT_MODEL_AMBIENT_SGIX',0x840A)
GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX=_C('GL_FRAGMENT_LIGHT_MODEL_LOCAL_VIEWER_SGIX',0x8408)
GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX=_C('GL_FRAGMENT_LIGHT_MODEL_NORMAL_INTERPOLATION_SGIX',0x840B)
GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX=_C('GL_FRAGMENT_LIGHT_MODEL_TWO_SIDE_SGIX',0x8409)
GL_LIGHT_ENV_MODE_SGIX=_C('GL_LIGHT_ENV_MODE_SGIX',0x8407)
GL_MAX_ACTIVE_LIGHTS_SGIX=_C('GL_MAX_ACTIVE_LIGHTS_SGIX',0x8405)
GL_MAX_FRAGMENT_LIGHTS_SGIX=_C('GL_MAX_FRAGMENT_LIGHTS_SGIX',0x8404)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glFragmentColorMaterialSGIX(face,mode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glFragmentLightModelfSGIX(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glFragmentLightModelfvSGIX(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glFragmentLightModeliSGIX(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glFragmentLightModelivSGIX(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glFragmentLightfSGIX(light,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glFragmentLightfvSGIX(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glFragmentLightiSGIX(light,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glFragmentLightivSGIX(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glFragmentMaterialfSGIX(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glFragmentMaterialfvSGIX(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glFragmentMaterialiSGIX(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glFragmentMaterialivSGIX(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetFragmentLightfvSGIX(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetFragmentLightivSGIX(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetFragmentMaterialfvSGIX(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetFragmentMaterialivSGIX(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glLightEnviSGIX(pname,param):pass



'''OpenGL extension NV.light_max_exponent

This module customises the behaviour of the 
OpenGL.raw.GL.NV.light_max_exponent to provide a more 
Python-friendly API

Overview (from the spec)
	
	Default OpenGL does not permit a shininess or spot exponent over
	128.0.  This extension permits implementations to support and
	advertise a maximum shininess and spot exponent beyond 128.0.
	
	Note that extremely high exponents for shininess and/or spot light
	cutoff will require sufficiently high tessellation for acceptable
	lighting results.
	
	Paul Deifenbach's thesis suggests that higher exponents are
	necessary to approximate BRDFs with per-vertex ligthing and
	multiple passes.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/light_max_exponent.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.light_max_exponent import *
from OpenGL.raw.GL.NV.light_max_exponent import _EXTENSION_NAME

def glInitLightMaxExponentNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension SGI.color_matrix

This module customises the behaviour of the 
OpenGL.raw.GL.SGI.color_matrix to provide a more 
Python-friendly API

Overview (from the spec)
	
	    This extension adds a 4x4 matrix stack to the pixel transfer path.  The
	    matrix operates on RGBA pixel groups, using the equation
	
		C' = MC,
	
	    where
	
		    |R|
		C = |G|
		    |B|
		    |A|
	
	    and M is the 4x4 matrix on the top of the color matrix stack.  After
	    the matrix multiplication, each resulting color component is scaled
	    and biased by a programmed amount.  Color matrix multiplication follows
	    convolution (and the scale, and bias that are associated with
	    convolution.)
	
	    The color matrix can be used to reassign and duplicate color components.
	    It can also be used to implement simple color space conversions.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGI/color_matrix.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGI.color_matrix import *
from OpenGL.raw.GL.SGI.color_matrix import _EXTENSION_NAME

def glInitColorMatrixSGI():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension AMD.transform_feedback4

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.transform_feedback4 to provide a more 
Python-friendly API

Overview (from the spec)
	
	Transform feedback is a mechanism to record the output of the vertex,
	tessellation evaluation or geometry shader into one or more buffers for
	further processing, recursive rendering or read-back by the client.
	ARB_transform_feedback3 (and OpenGL 4.0) extended the transform feedback
	subsystem to allow multiple streams of primitive information to be
	captured. However, it imposed a limitation that the primitive type for all
	streams must be POINTS if more than one stream is to be captured.
	AMD_transform_feedback3_lines_triangles relaxed that restriction to allow
	lines or triangles to be captured, in the case where multiple streams are
	to be processed. However, it still required that all streams share the same
	primitive type. Additionally, with all current extensions to transform
	feedback, only a single primitive stream may be rasterized.
	
	This extension enhances transform feedback in two significant ways. First,
	it allows multiple transform feedback streams to be captured, each with its
	own, independent primitve type. Second, it allows any combination of streams
	to be rasterized. As an example, this enables the geometry shader to take
	a single stream of triangle geometry and emit filled triangles with a
	wireframe outline and a point at each vertex, all in a single pass through
	the input vertices. Combined with features such those provided by
	ARB_viewport_array, layered rendering, shader subroutines and so on, an
	application can render several views of its geoemtry, each with a
	radically different style, all in a single pass.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/transform_feedback4.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.transform_feedback4 import *
from OpenGL.raw.GL.AMD.transform_feedback4 import _EXTENSION_NAME

def glInitTransformFeedback4AMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.shader_image_load_formatted

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.shader_image_load_formatted to provide a more 
Python-friendly API

Overview (from the spec)
	
	ARB_shader_image_load_store (and OpenGL 4.2) added support for
	random access load and store from/to texture images, but due to 
	hardware limitations, loads were required to declare the image
	format in the shader source. This extension relaxes that 
	requirement, and the return values from imageLoad can be format-
	converted based on the format of the image binding.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/shader_image_load_formatted.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.shader_image_load_formatted import *
from OpenGL.raw.GL.EXT.shader_image_load_formatted import _EXTENSION_NAME

def glInitShaderImageLoadFormattedEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_OES_blend_func_separate'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_OES_blend_func_separate',error_checker=_errors._error_checker)
GL_BLEND_DST_ALPHA_OES=_C('GL_BLEND_DST_ALPHA_OES',0x80CA)
GL_BLEND_DST_RGB_OES=_C('GL_BLEND_DST_RGB_OES',0x80C8)
GL_BLEND_SRC_ALPHA_OES=_C('GL_BLEND_SRC_ALPHA_OES',0x80CB)
GL_BLEND_SRC_RGB_OES=_C('GL_BLEND_SRC_RGB_OES',0x80C9)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glBlendFuncSeparateOES(srcRGB,dstRGB,srcAlpha,dstAlpha):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_KHR_cl_event2'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_KHR_cl_event2',error_checker=_errors._error_checker)
EGL_CL_EVENT_HANDLE_KHR=_C('EGL_CL_EVENT_HANDLE_KHR',0x309C)
EGL_SYNC_CL_EVENT_COMPLETE_KHR=_C('EGL_SYNC_CL_EVENT_COMPLETE_KHR',0x30FF)
EGL_SYNC_CL_EVENT_KHR=_C('EGL_SYNC_CL_EVENT_KHR',0x30FE)
@_f
@_p.types(_cs.EGLSyncKHR,_cs.EGLDisplay,_cs.EGLenum,ctypes.POINTER(_cs.EGLAttribKHR))
def eglCreateSync64KHR(dpy,type,attrib_list):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_OES_texture_3D'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_OES_texture_3D',error_checker=_errors._error_checker)
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_OES=_C('GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_OES',0x8CD4)
GL_MAX_3D_TEXTURE_SIZE_OES=_C('GL_MAX_3D_TEXTURE_SIZE_OES',0x8073)
GL_SAMPLER_3D_OES=_C('GL_SAMPLER_3D_OES',0x8B5F)
GL_TEXTURE_3D_OES=_C('GL_TEXTURE_3D_OES',0x806F)
GL_TEXTURE_BINDING_3D_OES=_C('GL_TEXTURE_BINDING_3D_OES',0x806A)
GL_TEXTURE_WRAP_R_OES=_C('GL_TEXTURE_WRAP_R_OES',0x8072)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLsizei,ctypes.c_void_p)
def glCompressedTexImage3DOES(target,level,internalformat,width,height,depth,border,imageSize,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glCompressedTexSubImage3DOES(target,level,xoffset,yoffset,zoffset,width,height,depth,format,imageSize,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glCopyTexSubImage3DOES(target,level,xoffset,yoffset,zoffset,x,y,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLint,_cs.GLint)
def glFramebufferTexture3DOES(target,attachment,textarget,texture,level,zoffset):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexImage3DOES(target,level,internalformat,width,height,depth,border,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexSubImage3DOES(target,level,xoffset,yoffset,zoffset,width,height,depth,format,type,pixels):pass



'''OpenGL extension EXT.cmyka

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.cmyka to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a simple method for OpenGL to read and store
	images whose pixels have CMYK or CMYKA formats.  The algorithms used to
	convert to RGBA from CMYKA and to convert back from RGBA to CMYKA are of
	the "black-box" nature, meaning that the application has little control
	over how the conversion is done.  Also, this black-box mechanism is
	available only for transfers to or from memory, not for internal copies
	of pixel data (such as invoked by CopyPixels, CopyTexImage1D, etc.)
	However, the defined mechanism nicely handles 5-component CMYKA images,
	and it is very easy to use.
	
	A more configurable and potentially higher quality color conversion can
	be implemented using the color tables, the color matrix, and possibly 3D
	and 4D texture lookup.  Such a color conversion also applies to copied
	pixel data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/cmyka.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.cmyka import *
from OpenGL.raw.GL.EXT.cmyka import _EXTENSION_NAME

def glInitCmykaEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION
from OpenGL import images as _i

_i.COMPONENT_COUNTS[ GL_CMYK_EXT ] = 4
_i.COMPONENT_COUNTS[ GL_CMYKA_EXT ] = 5



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_sRGB_formats'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_sRGB_formats',error_checker=_errors._error_checker)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT1_NV',0x8C4D)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT3_NV',0x8C4E)
GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV=_C('GL_COMPRESSED_SRGB_ALPHA_S3TC_DXT5_NV',0x8C4F)
GL_COMPRESSED_SRGB_S3TC_DXT1_NV=_C('GL_COMPRESSED_SRGB_S3TC_DXT1_NV',0x8C4C)
GL_ETC1_SRGB8_NV=_C('GL_ETC1_SRGB8_NV',0x88EE)
GL_SLUMINANCE8_ALPHA8_NV=_C('GL_SLUMINANCE8_ALPHA8_NV',0x8C45)
GL_SLUMINANCE8_NV=_C('GL_SLUMINANCE8_NV',0x8C47)
GL_SLUMINANCE_ALPHA_NV=_C('GL_SLUMINANCE_ALPHA_NV',0x8C44)
GL_SLUMINANCE_NV=_C('GL_SLUMINANCE_NV',0x8C46)
GL_SRGB8_NV=_C('GL_SRGB8_NV',0x8C41)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_OES_vertex_type_10_10_10_2'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_OES_vertex_type_10_10_10_2',error_checker=_errors._error_checker)
GL_INT_10_10_10_2_OES=_C('GL_INT_10_10_10_2_OES',0x8DF7)
GL_UNSIGNED_INT_10_10_10_2_OES=_C('GL_UNSIGNED_INT_10_10_10_2_OES',0x8DF6)




'''GLU extension EXT.object_space_tess
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes

GLU_OBJECT_PARAMETRIC_ERROR_EXT = constant.Constant( 'GLU_OBJECT_PARAMETRIC_ERROR_EXT', 100208 )
GLU_OBJECT_PATH_LENGTH_EXT = constant.Constant( 'GLU_OBJECT_PATH_LENGTH_EXT', 100209)

def gluInitObjectSpaceTessEXT():
    '''Return boolean indicating whether this module is available'''
    return extensions.hasGLUExtension( 'GLU_EXT_object_space_tess' )



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_framebuffer_mixed_samples'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_framebuffer_mixed_samples',error_checker=_errors._error_checker)
GL_COLOR_SAMPLES_NV=_C('GL_COLOR_SAMPLES_NV',0x8E20)
GL_COVERAGE_MODULATION_NV=_C('GL_COVERAGE_MODULATION_NV',0x9332)
GL_COVERAGE_MODULATION_TABLE_NV=_C('GL_COVERAGE_MODULATION_TABLE_NV',0x9331)
GL_COVERAGE_MODULATION_TABLE_SIZE_NV=_C('GL_COVERAGE_MODULATION_TABLE_SIZE_NV',0x9333)
GL_DEPTH_SAMPLES_NV=_C('GL_DEPTH_SAMPLES_NV',0x932D)
GL_EFFECTIVE_RASTER_SAMPLES_EXT=_C('GL_EFFECTIVE_RASTER_SAMPLES_EXT',0x932C)
GL_MAX_RASTER_SAMPLES_EXT=_C('GL_MAX_RASTER_SAMPLES_EXT',0x9329)
GL_MIXED_DEPTH_SAMPLES_SUPPORTED_NV=_C('GL_MIXED_DEPTH_SAMPLES_SUPPORTED_NV',0x932F)
GL_MIXED_STENCIL_SAMPLES_SUPPORTED_NV=_C('GL_MIXED_STENCIL_SAMPLES_SUPPORTED_NV',0x9330)
GL_MULTISAMPLE_RASTERIZATION_ALLOWED_EXT=_C('GL_MULTISAMPLE_RASTERIZATION_ALLOWED_EXT',0x932B)
GL_RASTER_FIXED_SAMPLE_LOCATIONS_EXT=_C('GL_RASTER_FIXED_SAMPLE_LOCATIONS_EXT',0x932A)
GL_RASTER_MULTISAMPLE_EXT=_C('GL_RASTER_MULTISAMPLE_EXT',0x9327)
GL_RASTER_SAMPLES_EXT=_C('GL_RASTER_SAMPLES_EXT',0x9328)
GL_STENCIL_SAMPLES_NV=_C('GL_STENCIL_SAMPLES_NV',0x932E)
@_f
@_p.types(None,_cs.GLenum)
def glCoverageModulationNV(components):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLfloatArray)
def glCoverageModulationTableNV(n,v):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLfloatArray)
def glGetCoverageModulationTableNV(bufsize,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLboolean)
def glRasterSamplesEXT(samples,fixedsamplelocations):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_EXT_create_context_es_profile'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_EXT_create_context_es_profile',error_checker=_errors._error_checker)
GLX_CONTEXT_ES_PROFILE_BIT_EXT=_C('GLX_CONTEXT_ES_PROFILE_BIT_EXT',0x00000004)




'''OpenGL extension APPLE.client_storage

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.client_storage to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a simple mechanism to optimize texture data handling
	by clients.  GL implementations normally maintain a copy of texture image
	data supplied clients when any of the various texturing commands, such as
	TexImage2D, are invoked.  This extension eliminates GL's internal copy of
	the texture image data and allows a client to maintain this data locally for
	textures when the UNPACK_CLIENT_STORAGE_APPLE pixel storage parameter is
	TRUE at the time of texture specification.  Local texture data storage is
	especially useful in cases where clients maintain internal copies of
	textures used in any case.  This results in what could be considered an
	extra copy of the texture image data.  Assuming all operations are error
	free, the use of client storage has no affect on the result of texturing
	operations and will not affect rendering results. APPLE_client_storage
	allows clients to optimize memory requirements and copy operations it also
	requires adherence to specific rules in maintaining texture image data.
	
	Clients using this extension are agreeing to preserve a texture's image data
	for the life of the texture.  The life of the texture is defined, in this
	case, as the time from first issuing the TexImage3D, TexImage2D or
	TexImage1D command, for the specific texture object with the
	UNPACK_CLIENT_STORAGE_APPLE pixel storage parameter set to TRUE, until the
	DeleteTextures command or another TexImage command for that same object. 
	Only after DeleteTextures has completed, or new texture is specified, can
	the local texture memory be released, as it will no longer be utilized by
	OpenGL.  Changing the UNPACK_CLIENT_STORAGE_APPLE pixel storage parameter
	will have no additional effect once the texturing command has been issued
	and specifically will not alleviate the client from maintaining the texture
	data.
	
	Client storage is implemented as a pixel storage parameter which affects
	texture image storage at the time the texturing command is issued.  As with
	other pixel storage parameters this state may differ from the time the
	texturing command in executed if the command is placed in a display list. 
	The PixelStore command is used to set the parameter
	UNPACK_CLIENT_STORAGE_APPLE.  Values can either be TRUE or FALSE, with TRUE
	representing the use of client local storage and FALSE indicating the OpenGL
	engine and not the client will be responsible for maintaining texture
	storage for future texturing commands issued per the OpenGL specification.
	The default state for the UNPACK_CLIENT_STORAGE_APPLE parameter is FALSE
	
	Client storage is only available for texture objects and not the default
	texture (of any target type).  This means that a texture object has to
	generated and bound to be used with client storage.  Setting
	UNPACK_CLIENT_STORAGE_APPLE to TRUE and texturing with the default texture
	will result in normally texturing with GL maintaining a copy of the texture
	image data.
	
	Normally, client storage will be used in conjunction with normal texturing
	techniques.  An application would use GenTextures to generate texture
	objects as needed.  BindTexture to the texture object name of interest. 
	Enable client storage via the PixelStore command setting the
	UNPACK_CLIENT_STORAGE_APPLE parameter to TRUE. Then use TexImage3D,
	TexImage2D or TexImage1D to specify the texture image.  If no further use of
	client storage is desired, it is recommended to again use the PixelStore
	command, in this case setting the UNPACK_CLIENT_STORAGE_APPLE parameter to
	FALSE to disable client storage, since this pixel state is maintained unless
	explicitly set by the PixelStore command.
	
	If an application needs to modify the texture, using TexSubImage for
	example, it should be noted that the pointer passed to TexSubImage1D,
	TexSubImage2D or TexSubImage3D does not have to the same, or within the
	original texture memory.  It if is not, there is the likelihood of GL
	copying the new data to the original texture memory owned by the client,
	thus actually modifying this texture image data.  This does not affect
	requirement to maintain the original texture memory but also does not add
	the requirement to maintain the sub image data, due to the copy.
	
	Once a client has completed use of the texture stored in client memory, it
	should issue a DeleteTextures command to delete the texture object or issue
	a texture command, with the same target type, for the object, with either a
	different data pointer, or UNPACK_CLIENT_STORAGE_APPLE set to false, in any
	case, breaking the tie between GL and the texture buffer.  An implicit Flush
	command is issued in these cases, ensuring all access to the texture by
	OpenGL is complete.  Only at this point can the texture buffer be safely
	released.  Releasing the texture buffer prior has undefined results and will
	very possibly display texel anomalies at run time.  System level memory
	management and paging schemes should not affect the use of client storage. 
	Consider in any case, that GL has an alias of the base pointer for this
	block of texture memory which is maintained until GL is finished rendering
	with the texture and it has been deleted or reassigned to another set of
	texture data.  As long as this alias exists, applications must not
	de-allocate, move or purge this memory.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/client_storage.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.client_storage import *
from OpenGL.raw.GL.APPLE.client_storage import _EXTENSION_NAME

def glInitClientStorageAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_ANDROID_image_native_buffer'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_ANDROID_image_native_buffer',error_checker=_errors._error_checker)
EGL_NATIVE_BUFFER_ANDROID=_C('EGL_NATIVE_BUFFER_ANDROID',0x3140)

